@@ -1,11 +1,9 @@
 package Data::DPath;
-# git description: v0.53-6-gb2f11f9
+# git description: v0.55-15-g75abea8
 
-BEGIN {
-  $Data::DPath::AUTHORITY = 'cpan:SCHWIGON';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: DPath is not XPath!
-$Data::DPath::VERSION = '0.54';
+$Data::DPath::VERSION = '0.56';
 use 5.008;
 use strict;
 use warnings;
@@ -70,7 +68,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -814,8 +812,10 @@ C<< $iterator->value->deref >>.
 The line B<#(2)> is utilizing the internal data structure to find out
 about the actual hash key under which the point is located. (There is
 also an official API to that: C<< $ancestor->first_point->attrs->key >>, 
-but there it's neccessary to check for undefined values before
+but there it's necessary to check for undefined values before
 calling the methods F<attrs> and F<key>, so I went the easy way).
+There's an equivalent attribute (C<idx>) for the array index of a point
+stored in an array.
 
 =head1 INTERNAL METHODS
 
@@ -876,7 +876,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2017 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
