@@ -1,9 +1,7 @@
 package Data::DPath::Context;
-BEGIN {
-  $Data::DPath::Context::AUTHORITY = 'cpan:SCHWIGON';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Abstraction for a current context that enables incremental searches
-$Data::DPath::Context::VERSION = '0.54';
+$Data::DPath::Context::VERSION = '0.56';
 use strict;
 use warnings;
 
@@ -26,13 +24,14 @@ our $THREADCOUNT;
 BEGIN {
         #$THREADCOUNT = $Data::DPath::PARALLELIZE ? Sys::CPU::cpu_count : 1;
         #print "THREADCOUNT: $THREADCOUNT\n";
-        package Data::DPath::Filters;
-BEGIN {
-  $Data::DPath::Filters::AUTHORITY = 'cpan:SCHWIGON';
-}
-$Data::DPath::Filters::VERSION = '0.54';
-$COMPARTMENT = Safe->new;
+        package
+          Data::DPath::Filters;
+
+        $COMPARTMENT = Safe->new;
         $COMPARTMENT->permit(qw":base_core");
+        $COMPARTMENT->permit(qw":load");
+        $COMPARTMENT->reval( 'no warnings;' ); # just so warnings is loaded
+        $COMPARTMENT->deny(qw":load");
         # map DPath filter functions into new namespace
         $COMPARTMENT->share(qw(affe
                                idx
@@ -133,11 +132,15 @@ sub _any
                                 keys %{$$ref};
                 }
                 elsif (ref($$ref) eq ARRAY or reftype($$ref) eq ARRAY) {
+                        my $idx = 0;
                         push @$out,
                             map {
-                                my $newpoint = Point->new->ref($_->{val_ref})->parent($point);
-                                push @newin, $newpoint; # remember added points
-                                $newpoint;
+                                 my $newpoint = Point->new
+                                                     ->ref($_->{val_ref})
+                                                     ->parent($point)
+                                                     ->attrs(Attrs->new(idx => $idx++));
+                                 push @newin, $newpoint; # remember added points
+                                 $newpoint;
                             }
                             map { { val_ref => \$_ } } @{$$ref}
                 }
@@ -200,11 +203,15 @@ sub _filter_points_eval
                                                        # 'uninitialized' values are the norm
                                                        # but "no warnings 'uninitialized'" does
                                                        # not work in this restrictive Safe.pm config, so
-                                                       # we deactivate warnings completely by localizing $^W
-                                                       $res = $COMPARTMENT->reval('local $^W;'.$filter);
+                                                       # we deactivate warnings completely by localizing $^W.
+                                                       # on later Perls, ^W doesn't do the whole trick, so explicitly turn
+                                                       # all warnings off.  need to do this in a BEGIN, as some warnings
+                                                       # are compile time only.
+                                                       $res = $COMPARTMENT->reval('BEGIN{ warnings->unimport}; local $^W;'.$filter);
                                                } else {
                                                        # 'uninitialized' values are the norm
                                                        no warnings 'uninitialized';
+                                                       no if $] >= 5.018, warnings => 'experimental::smartmatch';
                                                        $res = eval($filter);
                                                }
                                                print STDERR ($@, "\n") if $@;
@@ -319,8 +326,10 @@ sub _select_anystep {
                                 Point->new->ref($v_ref)->parent($point)->attrs($attrs)
                         } keys %$ref ];
                 } elsif (ref($ref) eq ARRAY or reftype($ref) eq ARRAY) {
+                        my $idx = 0;
                         $step_points = [ map {
-                                Point->new->ref(\$_)->parent($point)
+                                my $attrs = Attrs->new(idx => $idx++);
+                                Point->new->ref(\$_)->parent($point)->attrs($attrs)
                         } @$ref ];
                 } else {
                         if (ref($pref) eq SCALAR or reftype($pref) eq SCALAR) {
@@ -490,7 +499,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -598,7 +607,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2017 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
