@@ -1,9 +1,7 @@
 package Data::DPath::Filters;
-BEGIN {
-  $Data::DPath::Filters::AUTHORITY = 'cpan:SCHWIGON';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Magic functions available inside filter conditions
-$Data::DPath::Filters::VERSION = '0.54';
+$Data::DPath::Filters::VERSION = '0.56';
 use strict;
 use warnings;
 
@@ -69,6 +67,7 @@ sub reftype() {
 }
 
 sub is_reftype($) {
+        no warnings 'uninitialized';
         return (Scalar::Util::reftype($_) eq shift);
 }
 
@@ -76,7 +75,7 @@ sub is_reftype($) {
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -142,7 +141,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2017 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -155,7 +154,7 @@ __END__
 # sub parent, Eltern-Knoten liefern
 # nextchild, von parent und mir selbst
 # previous child
-# "." als aktueller Knoten, kind of "no-op", daran aber Filter verknüpfbar, löst //.[filter] und /.[filter]
+# "." als aktueller Knoten, kind of "no-op", daran aber Filter verknÃ¼pfbar, lÃ¶st //.[filter] und /.[filter]
 
 # IDEA: functions that return always true, but track stack of values, eg. last taken index
 #
